@@ -52,9 +52,6 @@ package com.openexchange.publish.microformats;
 import java.io.IOException;
 import java.io.PrintWriter;
 import java.io.UnsupportedEncodingException;
-import java.lang.reflect.InvocationHandler;
-import java.lang.reflect.Method;
-import java.lang.reflect.Proxy;
 import java.text.DateFormat;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
@@ -65,6 +62,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.TimeZone;
 import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.ajax.AJAXUtility;
@@ -103,7 +101,7 @@ public class MicroformatServlet extends OnlinePublicationServlet {
 
     private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(MicroformatServlet.class);
 
-    private static final Map<String, OXMFPublicationService> PUBLISHERS = new ConcurrentHashMap<String, OXMFPublicationService>();
+    private static final ConcurrentMap<String, PublicationAndVars> PUBLISHERS = new ConcurrentHashMap<String, PublicationAndVars>();
 
     private static final String MODULE = OXMFConstants.MODULE;
 
@@ -125,8 +123,6 @@ public class MicroformatServlet extends OnlinePublicationServlet {
         TIME_FORMAT.setTimeZone(TimeZone.getTimeZone("UTC"));
     }
 
-    private static final Map<String, Map<String, Object>> ADDITONAL_TEMPLATE_VARIABLES = new ConcurrentHashMap<String, Map<String, Object>>();
-
     private static volatile PublicationDataLoaderService dataLoader = null;
     private static volatile UserService userService;
     private static volatile StringTranslator translator;
@@ -151,8 +147,7 @@ public class MicroformatServlet extends OnlinePublicationServlet {
     }
 
     public static void registerType(final String module, final OXMFPublicationService publisher, final Map<String, Object> additionalVars) {
-        PUBLISHERS.put(module, publisher);
-        ADDITONAL_TEMPLATE_VARIABLES.put(module, additionalVars);
+        PUBLISHERS.putIfAbsent(module, new PublicationAndVars(publisher, additionalVars));
     }
 
     public static void setContactService(final ContactService service) {
@@ -177,18 +172,26 @@ public class MicroformatServlet extends OnlinePublicationServlet {
         try {
             resp.setContentType("text/html; charset=UTF-8");
             final Map<String, String> args = getPublicationArguments(req);
+            if (args==null){
+                final PrintWriter writer = resp.getWriter();
+                writer.println("The publication request is missing some or all parameters.");
+                writer.flush();
+                return;
+            }
+
             final String module = args.get(MODULE);
 
-            final OXMFPublicationService publisher = PUBLISHERS.get(module);
-            if (publisher == null) {
+            final PublicationAndVars publisherAndVars = PUBLISHERS.get(module);
+            if (publisherAndVars == null) {
                 final PrintWriter writer = resp.getWriter();
                 String escaped = Publications.escape(module, EscapeMode.HTML);
                 writer.println("The publication has either been revoked in the meantime or module \"" + escaped + "\" is unknown.");
                 writer.flush();
                 return;
             }
+
             final Context ctx = contexts.getContext(Integer.parseInt(args.get(CONTEXTID)));
-            final Publication publication = publisher.getPublication(ctx, args.get(SITE));
+            final Publication publication = publisherAndVars.publisher.getPublication(ctx, args.get(SITE));
             if (publication == null || !publication.isEnabled()) {
                 resp.setStatus(HttpServletResponse.SC_NOT_FOUND);
                 final PrintWriter writer = resp.getWriter();
@@ -207,7 +210,7 @@ public class MicroformatServlet extends OnlinePublicationServlet {
 
             Collection<? extends Object> loaded = dataLoader.load(publication, EscapeMode.HTML);
             User user = getUser(publication);
-            Contact userContact = getContact(new PublicationSession(publication), publication.getContext());
+            Contact userContact = getContact(new PublicationSession(publication));
 
             // Sanitize publication
             sanitizePublication(publication);
@@ -251,11 +254,9 @@ public class MicroformatServlet extends OnlinePublicationServlet {
             variables.put("userContact", userContact);
             variables.put("htmlService", new HTMLUtils(htmlService));
 
-            if (ADDITONAL_TEMPLATE_VARIABLES.containsKey(module)) {
-                variables.putAll(ADDITONAL_TEMPLATE_VARIABLES.get(module));
-            }
+            variables.putAll(publisherAndVars.variables);
 
-            final OXTemplate template = publisher.loadTemplate(publication);
+            final OXTemplate template = publisherAndVars.publisher.loadTemplate(publication);
             final AllocatingStringWriter htmlWriter = new AllocatingStringWriter();
             template.process(variables, htmlWriter);
             String html = htmlWriter.toString();
@@ -288,7 +289,7 @@ public class MicroformatServlet extends OnlinePublicationServlet {
         }
     }
 
-    private Contact getContact(final PublicationSession publicationSession, final Context context) throws OXException {
+    private Contact getContact(final PublicationSession publicationSession) throws OXException {
         return contacts.getUser(publicationSession, publicationSession.getUserId());
     }
 
@@ -303,7 +304,12 @@ public class MicroformatServlet extends OnlinePublicationServlet {
     }
 
     private Map<String, String> getPublicationArguments(final HttpServletRequest req) throws UnsupportedEncodingException {
-        final String[] path = SPLIT.split(req.getPathInfo(), 0);
+        final String[] path;
+        if(req.getPathInfo()==null){
+            path = new String[0];
+        } else {
+            path = SPLIT.split(req.getPathInfo(), 0);
+        }
         final List<String> normalized = new ArrayList<String>(path.length);
         for (int i = 0; i < path.length; i++) {
             if (!path[i].equals("")) {
@@ -311,6 +317,9 @@ public class MicroformatServlet extends OnlinePublicationServlet {
             }
         }
 
+        if(normalized.size()<2){
+            return null;
+        }
         final String site = Strings.join(HelperClass.decode(normalized.size() > 2 ? normalized.subList(2, normalized.size()) : normalized, req, SPLIT2), "/");
         final Map<String, String> args = new HashMap<String, String>();
         args.put(MODULE, normalized.get(0));
@@ -338,23 +347,18 @@ public class MicroformatServlet extends OnlinePublicationServlet {
         return AJAXUtility.encodeUrl(site, true, false);
     }
 
-    private static <T> T getProxy(Class<? extends T> intf, final T obj) {
-        return (T) Proxy.newProxyInstance(obj.getClass().getClassLoader(), new Class[] { intf }, new InvocationHandler() {
+    // --------------------------------------------------- Helper class -----------------------------------------------------
 
-            @Override
-            public Object invoke(Object proxy, Method method, Object[] args) throws Throwable {
-                String meth = method.getName();
-                if (!meth.startsWith("get")) {
-                    return method.invoke(obj, args);
-                }
+    private static final class PublicationAndVars {
 
-                Object retval = method.invoke(obj, args);
-                if (!(retval instanceof String)) {
-                    return retval;
-                }
-                return Publications.escape(retval.toString(), EscapeMode.HTML);
-            }
-        });
+        final OXMFPublicationService publisher;
+        final Map<String, Object> variables;
+
+        PublicationAndVars(OXMFPublicationService publicationService, Map<String, Object> variables) {
+            super();
+            this.publisher = publicationService;
+            this.variables = variables;
+        }
     }
 
 }
